==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="eu" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Sortu irudi-planoa...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Sortu 3D espazioaren irudi planarra</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>sortu irudi planarra 3D espazioan</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Ireki...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Ireki irudi-bista</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Kolore-espazioaren definitu gabeko mota irudia bistaratzeko</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Irudiaren pixel-formatua</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Aukeratu orientazioa</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Irudi-planoa</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY planoa</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ planoa</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ planoa</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Alderantzikatu norabidea</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Desplazamendua:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Egokitu irudia</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Luzatu irudia bista egokitzeko</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 eskala</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Erakutsi irudia 1:1 eskalan</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Jatorrizko kolorea</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Bistaratu irudia jatorrizko kolore(et)an</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>Kolore &amp;biziagoa</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Bistaratu irudia kolore biziagoekin</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Estandarra</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Prest...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grisa</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom-a</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>kanpo-irudia</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Irudi-ikustailea</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Irudiak (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Aukeratu irekiko den irudi-fitxategia</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Irudiak</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Fitxategi guztiak</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Errorea irudia irekitzean</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Ezin izan da hautatutako irudia kargatu</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Errorea irudia irekitzean</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Ezin izan da hautatutako irudia kargatu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="eu" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Sortu irudi-planoa...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Sortu 3D espazioaren irudi planarra</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>sortu irudi planarra 3D espazioan</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Ireki...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Ireki irudi-bista</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Eskala...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Irudia eskalatzea</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Kolore-espazioaren definitu gabeko mota irudia bistaratzeko</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Irudiaren pixel-formatua</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Aukeratu orientazioa</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Irudi-planoa</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY planoa</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ planoa</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ planoa</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Alderantzikatu norabidea</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Desplazamendua:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Egokitu irudia</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Luzatu irudia bista egokitzeko</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 eskala</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Erakutsi irudia 1:1 eskalan</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Jatorrizko kolorea</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Bistaratu irudia jatorrizko kolore(et)an</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>Kolore &amp;biziagoa</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Bistaratu irudia kolore biziagoekin</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Estandarra</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Prest...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grisa</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom-a</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>kanpo-irudia</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Irudi-ikustailea</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Irudiak (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Aukeratu irekiko den irudi-fitxategia</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Irudiak</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Fitxategi guztiak</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Errorea irudia irekitzean</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Ezin izan da hautatutako irudia kargatu</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Errorea irudia irekitzean</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Ezin izan da hautatutako irudia kargatu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Irudia</translation>
    </message>
  </context>
</TS>
